@@ -14,18 +14,10 @@
 # limitations under the License.
 
 from six.moves.urllib.parse import quote
-try:
-    # We need to import copy helper functions from copy middleware
-    # since it is introduced to swift.
-    from swift.common.middleware.copy import \
-        _check_copy_from_header as check_copy_from_header, \
-        _check_destination_header as check_destination_header, \
-        _copy_headers as copy_headers
-except ImportError:
-    # This is required to keep compatibility with
-    # swift < 2.8.0 which does not have COPY middleware.
-    from swift.common.constraints import check_copy_from_header, \
-        check_destination_header
+from swift.common.middleware.copy import \
+    _check_copy_from_header as check_copy_from_header, \
+    _check_destination_header as check_destination_header, \
+    _copy_headers as copy_headers
 from swift.common.swob import HTTPBadRequest, HTTPUnauthorized, \
     HTTPMethodNotAllowed, HTTPPreconditionFailed, HTTPForbidden
 from swift.common.utils import config_true_value, public, FileLikeIter, \
@@ -195,9 +187,9 @@ class StorletProxyHandler(StorletBaseHandler):
         acl_string = '.r:%s' % self._build_acl_string(user_name, storlet_name)
         try:
             clean_acl('X-Container-Read', acl_string)
-        except ValueError as e:
+        except ValueError as err:
             msg = ('storlet ACL update request has invalid values %s'
-                   % e.message)
+                   % str(err))
             raise HTTPBadRequest(msg.encode('utf8'))
 
         # Make sure the resulting acl permits a single entity
@@ -272,7 +264,7 @@ class StorletProxyHandler(StorletBaseHandler):
         Add to request the storlet parameters to be used in case the request
         is forwarded to the data node (GET case)
 
-        :param params: paramegers to be augmented to request
+        :param params: parameters to be augmented to request
         """
         for key, val in params.items():
             self.request.headers['X-Storlet-' + key] = val
